@@ -13,7 +13,7 @@ our @CARP_NOT = qw(
   Dumbbench::Result
 );
 
-our $VERSION = '0.10';
+our $VERSION = '0.501';
 
 require Exporter;
 
@@ -151,15 +151,19 @@ sub cmpthese {
 
   my @cols = map $_->[0], @sort_res;
   my @rows = (
-    ['', 'Rate', @cols]
+    ['', 'Rate/s', 'Precision/s', @cols]
   );
 
   foreach my $record (@sort_res) {
     my ($name, $bench, $rate) = @$record;
-    my $rstr = $bench->_rate_str($rate) . '/s';
+    my $rstr = $bench->_rate_str($rate);
+
     $rstr =~ s/\s+//g;
+
+    my @rstr = split /\+-/, $rstr;
+
     my @row;
-    push @row, $name, $rstr;
+    push @row, $name, @rstr;
 
     foreach my $cmp_record (@sort_res) {
       my ($cmp_name, $cmp_bench, $cmp_rate) = @$cmp_record;
@@ -471,9 +475,9 @@ Optionally calls C<timethese()>, then outputs a comparison chart.  This:
 
 outputs a chart like:
 
-                   Rate        b      a
-  b   5.75e+06+-47000/s       -- -70.1%
-  a 1.925e+07+-650000/s 235+-12%     --
+		 Rate/s Precision/s       a       b
+	a -3.59e+07       6e+06      -- -535.3%
+	b  8.24e+06      220000 -123.0%      --
 
 This chart is sorted from slowest to fastest, and shows the percent speed difference between each pair of tests
 as well as the uncertainties on the rates and the relative speed difference. The uncertainty on a speed difference
@@ -493,11 +497,11 @@ Returns a reference to an ARRAY of rows, each row is an ARRAY of cells from the
 
 returns a data structure like:
 
-  [
-    [ '',                 'Rate',        'b',      'a' ],
-    [ 'b',   '5.75e+06+-47000/s',       '--', '-70.1%' ],
-    [ 'a', '1.925e+07+-650000/s', '235+-12%',     '--' ],
-  ]
+        [
+          [ '', 'Rate/s', 'Precision/s', 'a', 'b' ],
+          [ 'a', '-4.43e+06', '120000', '--', '93+-6.9%' ],
+          [ 'b', '-2.294e+06', '52000', '-48.2%', '--' ]
+        ];
 
 =head1 METHODS
 
